/* Copyright (C) 2013  Stephan Kreutzer
 *
 * This file is part of csvpick.
 *
 * csvpick is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 or any later version,
 * as published by the Free Software Foundation.
 *
 * csvpick is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License 3 for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with csvpick. If not, see <http://www.gnu.org/licenses/>.
 */



#include <iostream>
#include <fstream>
#include <sstream>
#include <string>



int main(int argc, char* argv[])
{
    if (argc < 5)
    {
        std::cout << "Syntax:\n\tcsvpick csv-file-in csv-file-out columns-total selected-column" << std::endl;
        return 1;
    }
    
    std::ifstream csvin;
    
    csvin.open(argv[1], std::ios::binary);
    
    if (csvin.is_open() != true)
    {
        std::cout << "csvpick: Could not open file " << argv[1] << "." << std::endl;
        return 2;
    }
    
    std::ofstream csvout;
    
    csvout.open(argv[2], std::ios::binary | std::ios::app);
    
    if (csvout.is_open() != true)
    {
        std::cout << "csvpick: Could not open file " << argv[2] << "." << std::endl;
        return 2;
    }
    
    int nColumnsTotal = 0;
    int nSelectedColumn = 0;
    
    {
        std::stringstream convint;

        convint << argv[3];
    
        if (convint.fail() != false)
        {
            std::cout << "csvpick: " << argv[3] << " isn't a valid columns-total number." << std::endl;
            return 3;
        }
    
        convint >> nColumnsTotal;
        
        convint.str("");
        convint.clear();
        
        convint << argv[4];
        
        if (convint.fail() != false)
        {
            std::cout << "csvpick: " << argv[4] << " isn't a valid selected-column number." << std::endl;
            return 4;
        }
        
        convint >> nSelectedColumn;
    }
    
    if (nColumnsTotal <= 0)
    {
        std::cout << "csvpick: " << argv[3] << " isn't a valid columns-total number." << std::endl;
        return 3;
    }
    
    if (nSelectedColumn <= 0)
    {
        std::cout << "csvpick: " << argv[4] << " isn't a valid selected-column number." << std::endl;
        return 4;
    }


    std::string buffer;
    bool bContinue = true;
    
    while (bContinue == true)
    {
        for (int i = 0; i < nColumnsTotal; i++)
        {
            std::getline(csvin, buffer, ';');
        
            if ((i + 1) == nSelectedColumn)
            {
                csvout << buffer << ";" << std::endl;
            }
       
            if (csvin.fail() != false)
            {
                bContinue = false;
                break;
            }
        }
    }

    return 0;
}
